@@ -1660,7 +1660,7 @@ use warnings;
 
 package Devel::PerlySense;
 {
-  $Devel::PerlySense::VERSION = '0.0201';
+  $Devel::PerlySense::VERSION = '0.0202';
 }
 
 
@@ -1848,6 +1848,14 @@ Die on errors (like if the file wasn't found).
 sub oDocumentParseFile {
 	my ($file) = @_;
 
+    # Stop recursive lookups
+    if( exists $self->rhFileDocumentCache->{$file}) {
+        if(! defined $self->rhFileDocumentCache->{$file}) {
+            die("Tried to parse ($file) recursively\n");
+        }
+    }
+    $self->rhFileDocumentCache->{$file} = undef;
+
     my $oDocument = $self->rhFileDocumentCache->{$file} ||= do {
         my $oDocumentNew = Devel::PerlySense::Document->new(oPerlySense => $self);
         $oDocumentNew->parse(file => $file);
@@ -2499,10 +2507,36 @@ sub fileFindLookingAround {
                 # Are we expecting a module name? If not, it's a match.
                 $nameModule or return(file($fileFound)->absolute . "");
 
+
+                # Check for the dir above the file, is there a package
+                # name like that in the file? If so, this one isn't
+                # it.
+                # If I do this, the next one might not even be needed
+
+
                 # Does the file contain a Package declaration for the
-                # module name?
-                my $oDocumentFound = $self->oDocumentParseFile($fileFound) or next;
-                if( first { $_ eq $nameModule } $oDocumentFound->aNamePackage) {
+                # module name? This is a manual and cheap workaround
+                # to avoid recursive and slow parse
+                my $textFile = file($fileFound)->slurp();
+                if($textFile =~ m|
+                    package          # package declaration
+                    \s+
+                    [^;]*?           # up until until the next
+                                     # statement separator (fragile,
+                                     # could well be in comments or a
+                                     # block)
+                    (?<!::)          # Not preceeded by a module
+                                     # separator, i.e. it's not a
+                                     # module shadowing the shorter
+                                     # name
+                    $nameModule
+                    \b
+                    (?!::)           # Not followed by a module
+                                     # separator, i.e. it's not a
+                                     # longer, other module
+                |xsm) {
+                    ###TODO: possibly check using parse here, now that
+                    ###we know the package name is in there.
                     return(file($fileFound)->absolute . "");
                 }
             }
