@@ -33,7 +33,7 @@ use warnings;
 
 package Devel::PerlySense::Document;
 {
-  $Devel::PerlySense::Document::VERSION = '0.0201';
+  $Devel::PerlySense::Document::VERSION = '0.0202';
 }
 
 
@@ -845,6 +845,10 @@ sub determineLikelyApi0 {
             dirOrigin => dirname($self->file),
         ) or next;
 
+        debug("($nameModule) looking in base class ($nameBase)");
+        $nameModule eq $nameBase and next;
+        ###TODO: look for longer recursive chains
+
         $oDocumentBase->determineLikelyApi(nameModule => $nameBase);
 
         $self->mergePackageApiWithBase(
